/*
		File:		Clicker Glue.h
		
		Contents:	Header file for Clicker glue code
		
		Copyright:	 by Manuel Kasper, Blue Ice Software.
					All rights reserved.
*/

/*
	Note that the routines listed here should work with every version of Clicker, starting
	with v4.0. If i make changes to the internal data structures, i'll make them in a way
	that is compatible with existing programs using the glue.
*/

/* This enum's define the actions you can set on or off using SetActionBit() */
enum {
	mouseDownBit = 0,		/* Sound on Mouse Down */
	mouseUpBit,				/* Sound on Mouse Up */
	keyDownBit,				/* Sound on Key Down */
	spaceBit,				/* Sound on Space */
	returnBit,				/* Sound on Return */
	tabBit,					/* Sound on Tab */
	deleteBit				/* Sound on Delete */
};

/* This routine determines whether Clicker is installed. */
Boolean ClickerIsInstalled(void);

/* Use this routine to determine whether Clicker is on or off. */
Boolean ClickerOn(void);

/* Use this routine to set Clicker on or off */
void SetClicker(Boolean ClickerOn);

/* Use this routine to set the action bits. */
void SetActionBit(short theAction, Boolean SetOn);

/* Gives you the number of mouse clicks the user has done */
long GetMouseClicks(void);

/* Gives you the number of key clicks the user has done */
long GetKeyClicks(void);

/* Gives you the date/time of the last reset as seconds since midnight, 1/1/04. */
unsigned long GetSince(void);

/* This routines gives you the name of the user (if registered), or "Not registered" otherwise. */
void GetUserName(Str255 theName);

/* This routine tries to open the Clicker Control Panel by doing the following steps:

	1.	Locate the Control Panels Folder using FindFolder()
	2.	Using PBGetCatInfo(), index through all files in the directory until it finds one with
		type = 'CliX'.
	3.	Find the Finder process (required, because it opens the CP)
	4.	Set the selection to the Clicker Control Panel using the Alias and AE Manager,
		then send an open selection event
*/
void OpenControlPanel(void);